News — SnapPy 2.7 documentation

# News

- Version 2.7 (July 2019): New features include:
  - Python 3 is now recommended over Python 2 on all platforms; the default Mac and Windows apps use Python 3 rather than Python 2. The only difference most users will notice is that one must type `print(blah)` instead of `print blah`.
  - Verified computations: performance improvements by switching to the Krawczyk test.
  - Support for SageMath 8.8.
  - Installation instructions extensively updated.
  - GUI improvements, especially on macOS. These include improved support for dark mode and tabs on macOS Mojave and preliminary support for macOS Catalina.
- Version 2.6.1 (August 2018): New features include:
  - Support for SageMath 8.3, Python 3.7, and macOS Mojave.
  - Computing ideals defining SL(2, C) character varieties. Contributed by Jean-Philippe Burelle, based on this paper.
  - Many bug fixes.
- Version 2.6 (Nov 2017): New features include:
  - Support for macOS High Sierra, SageMath 8.1, and Windows systems using non-Latin alphabets.
  - Many bug fixes, including improved Python 3 support.
- Version 2.5 (Feb 2017): New features include:
  - Rigorous computation of hyperbolic volume.
  - STL export of Dirichlet domains for 3D printing, contributed by Jose Sanchez.
  - Support for Python 3, SageMath 7.5, 7.6, and 8.0, and many more versions of Python on Windows.
  - Much improved infrastructure for testing and distributing SnapPy.
- Version 2.4 (May 2016): New features include:
  - Added census of Platonic manifolds.
  - Rigorous computation of cusp translations.
  - Added decorations to triangulation isomorphism signatures for encoding peripheral curves.
  - Faster verification of non-tetrahedral canonical cell decompositions.
  - Improvements to the link and planar diagram component, mostly contributed by Malik Obeidin, include:
    - Bar-Natan’s super-fast tangle-based algorithm for computing the Alexander polynomial.
    - Can now compute the Seifert matrix and express a link as a braid closure.
    - Conversion to/from SageMath links and braids.
    - Many under-the-hood improvements.
  - New Windows installer.
- Version 2.3 (March 2015): New features include:
  - Major improvements to the link and planar diagram component, including link simplification, random links, and better documentation.
  - Basic support for spun normal surfaces.
  - New extra features when used inside of Sage:
    - HIKMOT-style rigorous verification of hyperbolic structures, contributed by Matthias Goerner.
    - Many basic knot/link invariants, contributed by Robert Lipschitz and Jennet Dickinson.
    - Sage-specific functions are now more easily accessible as methods of Manifold and better documented.
    - Improved number field recognition, thanks to Matthias.
  - Better compatibility with OS X Yosemite and Windows 8.1.
  - Development changes:
    - Major source code reorganization/cleanup.
    - Source code repository moved to Bitbucket.
    - Python modules now hosted on PyPI, simplifying installation.
- Version 2.2 (June 2014): Includes Ben Burton’s census of orientable cusped manifolds with 9 tetrahedra.
- Version 2.1 (February 2014): New high-precision manifolds (ManifoldHP) which compute hyperbolic stuctures (and everything related) in quad-double (212 bit) precision.
- Version 2.0 (September 2013): Many new features, including:
  - A manifold browser window for easily examining a particular manifold.
  - Many improvements to the link editor, including
    - A smoothed view mode with image export to EPS/PDF/SVG/TikZ.
    - Producing a fully editable link from combinatorial data like a DT code.
  - Splitting manifolds along surfaces of non-negative euler characteristic.
  - Generalizing the ptolemy obstruction class to allow computation of PGL(3,C)-representations and improving usability of the ptolemy module.
  - CensusKnots now includes knot exteriors with 8 tetrahedra.
- Version 1.8 (May 2013) improves handling of DT codes and adds the HTLinkExteriors census, which provides identification for knots and links up to 14 crossings.
- Version 1.7 (November 2012) incorporates the ptolemy module for studying representations of 3-manifold groups into pSL(N, C).
- Version 1.6 (August 2012) includes a new way to make links and some support for arbitrary precision calculation.
- Version 1.5 (February 2012) includes much improved manifold censuses.
- Version 1.4 (December 2011) uses the current release of IPython, which has been completely rewritten.
- Version 1.3.10 (July 2011) incorporates Twister; a useful users guide.
- Version 1.3 (February 2011) has a completely redesigned cusp horoball viewer and many bug fixes!
- Version 1.2 (December 2010).
- Version 1.1 (February 2010).
- Version 1.0 (August 2009) Initial version.